declare module BA.Ui.ClientSideControls.List {
    /**
     * This class implements a highly customizable list. It needs a service controller to get its data from and
     * optionally its meta data (columns, actions, filters, etc), too.
     */
    class ListControl {
        /** actually the dxDataGrid instance that is created */
        private instance;
        /** the div element that was used to create the list on */
        private anchor;
        /** the hover actions that are displayed over each row */
        private rowActions;
        /** the action method id to be invoked when a list row is clicked */
        private rowClickMethodId;
        /** the action method id to be invoked when a list row is double clicked */
        private rowDoubleClickMethodId;
        /** additional parameters which will be sent to the data service with each request */
        private additionalServiceParameters;
        private showTotalCount;
        private contentReadyMethodId;
        private key;
        customCreateProperties: CustomData;
        /** Load events */
        OnBeginCallback: Function;
        OnEndCallback: Function;
        /**
         * Creates a new client side list using the given create-parameters.
         *
         * @param createParameters
         */
        constructor(createParameters: ListControlCreateParameters);
        /**
         * Creates the data store for the data grid object.
         * By default, it creates a data store for connecting to a remote site (data source controller).
         * This might be overridden with an own data store in sub classes.
         *
         * @param createParameters
         */
        protected GetDataStore(createParameters: ListControlCreateParameters): DevExpress.data.CustomStore;
        /**
         * Gets the options for the data grid.
         * This function can be overridden in order to create either own options or make changes to these prior
         * to creating the data grid.
         *
         * @param dataStore
         */
        protected GetDataGridOptions(dataStore: DevExpress.data.CustomStore, createParameters: ListControlCreateParameters): DevExpress.ui.dxDataGrid.Properties;
        /**
         * Returns the template function that is used to render all (but the command-) columns. May be overridden in
         * inheriting classes.
         *
         * @param defaultTemplateFunction
         */
        protected GetColumnTemplate(defaultTemplateFunction: (evt: DevExpress.ui.dxDataGrid.CellPreparedEvent<any, any>) => any): (evt: DevExpress.ui.dxDataGrid.CellPreparedEvent<any, any>) => any;
        /**
         * The template for the dxDataGrid's command column. The cmd column is used for the hover-actions, this template
         * here tweaks the column and its contents a bit so they are displayed the way we want.
         *
         * @param cellElement
         * @param cellInfo
         */
        protected CommandColumnTemplate(cellElement: DevExpress.core.DxElement, cellInfo: DevExpress.ui.dxDataGrid.ColumnCellTemplateData<any, any>): JQuery;
        /**
         * This returns the html to be used for all content cells of the dxDataGrid.
         * Here the types of content are rendered differently and the optional styles, that might be connected with
         * most types of content, are applied.
         *
         * @param evt
         */
        protected RegularColumnTemplate(evt: DevExpress.ui.dxDataGrid.CellPreparedEvent<any, any>): void;
        /**
         * Event handler when the hover state of a cell changes. Handles hiding and showing of the row actions.
         *
         * @param evt
         */
        protected HandleOnCellHoverChanged(evt: DevExpress.ui.dxDataGrid.CellHoverChangedEvent<any, any>): void;
        /** Returns the dxDataGrid instance of this list control */
        GetListInstance(): List;
        /**
         * The default function for rendering image column entries.
         *
         * @param evt
         */
        static DefaultRenderImage(evt: DevExpress.ui.dxDataGrid.CellPreparedEvent<any, any>): void;
        /**
         * The default function for rendering standard multi-line text/numbers/dates.
         *
         * @param evt
         */
        static DefaultRenderMultiLine(evt: DevExpress.ui.dxDataGrid.CellPreparedEvent<any, any>): void;
        /**
         * Converter function that uses DevExpress.localization for formatting numbers to the user's locale format.
         *
         * @param value
         */
        static ConvertNumberToString(value: any): string;
        /**
         * Converter function that uses DevExpress.localization for formatting dates (only) to the user's locale format.
         *
         * @param value
         */
        static ConvertDateToString(value: any): string;
        /**
         * Converter function that uses DevExpress.localization for formatting dates (with times) to the user's locale format.
         *
         * @param value
         */
        static ConvertDateTimeToString(value: any): string;
        /**
         * This function is used for creating a new list on the given anchor (div-) element. You must give a data source
         * controller name (url will be calculated) where both data and meta data will be retrieved from. With the
         * 'toolbarElements' parameter you can decide, which of the available toolbar elements the toolbar should
         * contain. The additionalServiceParameters are parameters which your data source controller needs with each
         * request. Returns a promise that can be used with the usual done() and fail() methods.
         *
         * @param anchor the div element the list is created on
         * @param listDataController the name of the controller that is used as datasource controller for retrieving
         *                  data and meta data. The name must not contain the 'Controller' suffix and the controller
         *                  itself must implement IListControlDataSource on the server side.
         * @param toolbarElements string that contains the general toolbar elements that should be used as a comma
         *                  seperated list; currently these consist only of 'filters'.
         * @param additionalServiceParameters parameters which are sent to the controller with each request.
         */
        static CreateListFromController(anchor: ListContainer, listDataController: string, toolbarElements: ToolbarElements, additionalServiceParameters?: CustomData): JQueryPromise<unknown>;
        /**
         * Creates a new list control using the given create-parameters and returns it.
         *
         * @param createParameters
         */
        static CreateListFromParameters(createParameters: ListControlCreateParameters): ListControl;
    }
}
