declare module BA.Ui {
    /**
     * Helper class to perform Actions with OpenAI
     */
    class OpenAIUtils {
        /**
         * oid of a chat entry during live update
         */
        private static readonly chatEntryInLiveUpdateId;
        /**
         * function to call Open AI without the result dialog showing (streamed)
         * @param actionName Name of the Server Action, if null the default action will be called
         * @param clientCommunicationModel The clientCommunicationModel to use
         * @param fieldName Name of the field to update
         * @param liveStreamUpdateAction MethodId of the action that should be called for live updating
         * @param customData optional string representation of additional information that is passed to the liveStreamUpdateAction
         * @param onBeforeStreaming optional Method to be called before the streaming starts
         * @param onDone Method to be called when the streaming is finished
         * @param onError Method to be called on error
         */
        static GetResponseStreamed(actionName: string, clientCommunicationModel: BA.Ui.Models.OpenAIClientCommunicationModel, fieldName: string, liveStreamUpdateAction: string, customData?: string, onBeforeStreaming?: () => void, onDone?: (response: BA.Ui.Models.OpenAIClientCommunicationModel) => void, onError?: () => void): any;
        /**
         * Function to Call OpenAI Chat dialog
         * @param actionName Name of the Server Action, if null the default action will be called
         * @param clientCommunicationModel The clientCommunicationModel to use
         * @param onDone Method to be called when the streaming is finished
         * @param onError Method to be called on error
         */
        static GetResponseStreamedInDialog(actionName: string, clientCommunicationModel: BA.Ui.Models.OpenAIClientCommunicationModel, onDone?: (response: BA.Ui.Models.OpenAIClientCommunicationModel) => void, onError?: () => void): any;
        /**
         * Format a result string as HTML
         * @param result the result string
         * @returns result string formatted as HTML
         */
        static FormatAsHTML(result: string): string;
        /**
         * Function to be called when the dialog is either initialized or refreshed
         * */
        static InitOpenAIChatDialog(sender: BAClientPopupControl): void;
        /**
         * Method to select an assistant-entry
         * @param s the dialog
         * @param entry the entry to select
         */
        private static SelectAssistantEntry;
        /**
         * Helper function to get the control for current message
         * @param dialog die DialogPopup
         * @returns The Control for the current message
         */
        private static GetCurrentMessageControl;
        /**
         * Send a chst message
         * @param s The button that was clicked
         * @param e
         */
        static SendChatMessage(s: any, e: any): void;
        /**
         * Update the Chat UI and start streaming
         * @param s
         * @param createUserEntry
         * @param actionName
         */
        private static UpdateChatUIAndStream;
        /**
         * Create a chat message of the user
         * @param text The text to be displayed
         * @param insertContainer the container to insert the chatEntry to
         * @param lastEntry The last entry
         * @returns the Element of the chat entry
         */
        private static CreateChatMessageUser;
        /**
         * Create a chat message of the assistant
         * @param insertContainer the container to insert the chatEntry to
         * @param lastEntry The last entry
         * @returns the Element of the chat entry
         */
        private static CreateChatMessageAssistant;
        /**
         * Function that is called to live update the chat
         * @param content The content of the assistant message
         */
        static LiveUpdateChat(content: any): void;
        /**
         * Update the Dialog with Data in the ClientCommunicationModel
         * @param sender The DialogPopup
         * @param clientCommunicationModel The clientCommunicationModel
         */
        private static UpdateDialogFromClientCommunicationModel;
        /**
         * Update the ClientCommunicationModel with Data in the Dialog
         * @param dialog The dialog popup
         * @param clientCommunicationModel The clientCommunicationModel
         * @returns The updated ClientCommunicationModel
         */
        private static UpdateClientCommunicationModelFromDialog;
        /**
         * Get the value of a control insode the Dialog and set it to null
         * @param fieldName fieldName of the control
         * @param dialog The dialog popup
         * @param clientCommunicationModel The clientComminocationModel
         * @returns The value of the control (before it was set to null)
         */
        private static GetControlValueFromDialogAndSetNull;
        static OpenAIOkButtonClicked(s: any, e: any): void;
    }
}
