declare module BA.Ui.Pages {
    class Page {
        _PageLoaded: boolean;
        Id: BA.Classes.Guid;
        PageConfigId: BA.Classes.Guid;
        Widgets: Array<BA.Ui.Widgets.Widget>;
        CatalogueWidgets: Array<BA.Ui.Widgets.Widget>;
        /**
         * Creates an instance of Page
         *
         * @param pageConfigId guid of the page configuration for the page
         * @param renderedWidgetsCount number of widgets rendered in the page
         */
        constructor(pageConfigId: BA.Classes.Guid);
        private AreAllWidgetsAdded;
        /**
         * Adds a Widget to the list of widgets of this page. It calls the OnPageLoaded function if all widgets are loaded
         *
         * @param widget an instance of BA.Ui.Widgets.Widget
         */
        AddWidget(widget: BA.Ui.Widgets.Widget): void;
        /**
         * Adds a Widget to the list of widgets in the catalogue of this page.
         *
         * @param widget an instance of BA.Ui.Widgets.Widget
         */
        AddWidgetToCatalogue(widget: BA.Ui.Widgets.Widget): void;
        /**
         * Checks if the widget with given id is in the catalogue
         *
         * @param id of the widget to look for
         */
        IsWidgetInCatalogue(id: Classes.Guid): boolean;
        /**
         * Moves a Widget from the list of widgets of the page to the catalogue of this page.
         *
         * @param widget an instance of BA.Ui.Widgets.Widget
         */
        MoveWidgetToCatalogue(widget: BA.Ui.Widgets.Widget): void;
        /**
         * Moves a Widget from the catalogue to the list of widgets of this page.
         *
         * @param widget an instance of BA.Ui.Widgets.Widget
         */
        MoveWidgetToPage(widget: BA.Ui.Widgets.Widget): void;
        /**
         * Removes the widget from the page or catalogue
         *
         * @param widget an instance of BA.Ui.Widgets.Widget
         */
        RemoveWidget(widget: BA.Ui.Widgets.Widget): void;
        /**
         * Returns the BA.Ui.Widgets.Widget in the list of widgets with Id equal to the parameter, if any.
         *
         * @param id of the widget to look for
         */
        GetWidget(id: BA.Classes.Guid): BA.Ui.Widgets.Widget;
        /**
         * Function called when all widgets of the page are loaded.
         */
        OnPageLoaded(): void;
        ShowPageMenu(): void;
        HidePageMenu(): void;
        /**
         * Function called when the tab containing the page is activated
         */
        private OnTabActivated;
        /**
         * Default focus in the page to focus the corresponding widget
         */
        FocusDefaultWidget(): void;
    }
}
