declare module BA.Ui.Translations {
    class TranslationTools {
        private TranslationDictionary;
        Locale: string;
        constructor();
        /**
         * Gets a translation from the local dictionary or the server and executes a callback function when finished with the result as parameter.
         * If the translation does not exist in the server, the searched identifier will be saved in the dictionary.
         *
         * @param translationGuid string. Identifier of the translation to get.
         * @param callback function. Callback function to execute after this method.
         * @param showWaitAnimation (optional) boolean. If true, the application shows a loading animation during the process.
         */
        static GetTranslation(translationGuid: string, callback: (result: string) => void, showWaitAnimation?: boolean): void;
        /**
         * Gets a translation from the local dictionary. If it is not there it shows a fallback value instead of seaching in the server.
         *
         * @param translationGuid string. Identifier of the translation to get.
         * @param fallbackValue (optional) string. String to return if the translation wanted is not in the local dictionary.
         */
        static TryGetTranslation(translationGuid: string, fallbackValue?: string): string;
        /**
         * Gets a list of translations from the local dictionary or the server and executes a callback function when finished with the results as parameter.
         * It also handles the posibility of a subset of the translations being already in the local dictionary.
         * If any translation does not exist in the server, the searched identifier will be saved in the dictionary.
         *
         * @param translationGuid string array. Identifiers of the translations to get.
         * @param callback function. Callback function to execute after this method.
         * @param showWaitAnimation (optional) boolean. If true, the application shows a loading animation during the process.
         */
        static GetTranslations(translationGuids: string[], callback: (results: TranslationDictionary) => void, showWaitAnimation?: boolean): void;
        /**
         * Gets a translation from the server and stores it in the local dictionary so it is prepared for future usage.
         * If the translation does not exist in the server, the searched identifier will be saved in the dictionary.
         *
         * @param translationGuid string. Identifier of the translation to get.
         * @param showWaitAnimation (optional) boolean. If true, the application shows a loading animation during the process.
         */
        static PrepareTranslation(translationGuid: string, showWaitAnimation?: boolean): void;
        /**
         * Gets one or multiple translations from the server and stores them in the local dictionary so it is prepared for future usage.
         * If any translation does not exist in the server, the searched identifier will be saved in the dictionary.
         *
         * @param translationGuid string array. Identifiers of the translations to get.
         * @param showWaitAnimation (optional) boolean. If true, the application shows a loading animation during the process.
         */
        static PrepareTranslations(translationGuids: string[], showWaitAnimation?: boolean): void;
        /**
         * Private function for internal use to get a translation from the server and store it in the local dictionary. It executes a callback function when finished with the result as parameter.
         * If the translation does not exist in the server, the searched identifier will be saved in the dictionary.
         *
         * @param translationGuid string. Identifier of the translation to get.
         * @param callback function. Callback function to execute after this method.
         * @param showWaitAnimation (optional) boolean. If true, the application shows a loading animation during the process.
         */
        private GetTranslationFromServer;
        /**
         * Private function for internal use to get a list of translations from the server and save them in the local dictionary. It executes a callback function when finished with the results as parameter.
         * If any translation does not exist in the server, the searched identifier will be saved in the dictionary.
         *
         * @param translationGuid string array. Identifiers of the translations to get.
         * @param callback function. Callback function to execute after this method.
         * @param showWaitAnimation (optional) boolean. If true, the application shows a loading animation during the process.
         */
        private GetTranslationsFromServer;
        /**
         * Private function for internal use to add an entry of the local dictionary.
         *
         * @param key string. Identifier of the translation.
         * @param value string. Text of the translation.
         */
        private AddTranslation;
        /**
         * Private function for internal use to get an entry of the local dictionary.
         *
         * @param key string. Identifier of the translation to get.
         */
        private GetTranslationInternal;
    }
}
